@@ -28,6 +28,32 @@ HTTP::MultiGet - Run many http requests at once!
   }
 
 
+Handling Streams of data
+
+  use Modern::Perl;
+  use HTTP::MultiGet;
+  use HTTP::Request;
+
+  my $req=HTTP::Request->new(GET=>'http://some.realy.big/file/to/download.gz');
+  my $on_body=sub {
+    my ($getter,$id,$headers,$body)=@_;
+      # 0: Current HTTP::MultiGet instance
+      # 1: Id of current job
+      # 2: HTTP::Headers object
+      # 3: Chunk of data being downloaded
+    if($headers->code==200) {
+      # do something
+    } else {
+      # do something with $body
+    }
+  };
+  my $getter=new HTTP::MultiGet;
+  my ($result)=$getter->run_requests([$req,on_body=>$on_body]);
+
+  # the on_body=>$on_body is called on each chunk downloaded
+  # $result is created when the download is completed.
+  # but $result->decoded_content is empty!
+
 If you want more control
 
   use Modern::Perl;
@@ -64,10 +90,6 @@ use Log::Log4perl;
 use Data::Queue;
 use Scalar::Util qw(looks_like_number);
 Log::Log4perl->wrapper_register(__PACKAGE__);
-BEGIN {
-with 'Log::LogMethods';
-with 'Data::Result::Moo';
-}
 use AnyEvent::Loop;
 use Data::Dumper;
 use HTTP::Response;
@@ -77,7 +99,13 @@ use AnyEvent::HTTP::Request;
 use MooX::Types::MooseLike::Base qw(:all);
 use AnyEvent::HTTP::Response;
 use Carp qw(croak);
-our $VERSION='1.002';
+use Ref::Util qw(is_plain_arrayref);
+use namespace::clean;
+BEGIN {
+with 'Log::LogMethods';
+with 'Data::Result::Moo';
+}
+our $VERSION='1.003';
 
 sub BUILD {
   my ($self)=@_;
@@ -453,15 +481,37 @@ Internal method.  Returns a new instance of $self->SENDER_CLASS for Teh given $r
 =cut 
 
 sub create_request {
-  my ($self,$req,$id)=@_;
-
-  my $code=$self->que_function($req,$id);
+  my ($self,$obj,$id)=@_;
+  
+  my $req;
+  my $opt={
+      params=>{%{$self->request_opts}},
+  };
+  if(is_plain_arrayref($obj)) {
+    my @args;
+    ($req,@args)=@{$obj};
+    my $code=$self->que_function($req,$id);
+    while(my ($key,$value)=splice(@args,0,2)) {
+      if($key eq 'on_body') {
+        my $code=sub {
+	   my ($body,$headers)=@_;
+	   my $header=new HTTP::Headers( %{$headers});
+	   $value->($self,$id,$header,$body);
+	};
+	$opt->{params}->{$key}=$code;
+      } else {
+        $opt->{params}->{$key}=$value;
+      }
+    }
+    $opt->{cb}=$code;
+  } else {
+    $req=$obj;
+    my $code=$self->que_function($req,$id);
+    $opt->{cb}=$code;
+  }
   my $request=$self->SENDER_CLASS->new(
     $req,
-    {
-      cb=>$code,
-      params=>$self->request_opts,
-    }
+    $opt,
   );
 
   return $request;
